@@ -31,7 +31,6 @@ def deploy_project():
     virtualenv.virtualenv_create()
     make_clone()
 
-#    virtualenv.pip_setup_conf()
     virtualenv.pip_install(env.conf.PIP_REQUIREMENTS, restart=False)
 
     setup_web_server()
@@ -79,18 +78,26 @@ def setup_web_server():
     apache.apache_setup()
     nginx.nginx_setup()
 
-def push(*args):
+def push(*args, **kwargs):
     ''' Run it instead of your VCS push command.
 
-    Arguments:
+    The following strings are allowed as positional arguments:
+
+    * 'notest' - don't run tests
+    * 'syncdb' - run syncdb before code reloading
+    * 'migrate' - run migrate before code reloading
+    * 'pip_update' - run virtualenv.pip_update before code reloading
+    * 'norestart' - do not reload source code
+
+    Keyword arguments:
+
+    * before_restart - callable to be executed after code uploading
+      but before the web server reloads the code.
+
+    Customization example can be found  :ref:`here <fab-push-customization>`.
 
-    * test - don't run dj_cmd.tests
-    * syncdb - run dj_cmd.syncdb before code reloading
-    * migrate - run dj_cmd.migrate before code reloading
-    * pip_update - run virtualenv.pip_update before code reloading
-    * norestart - do not reload source code
     '''
-    allowed_args = set(['test', 'syncdb', 'migrate', 'pip_update', 'norestart'])
+    allowed_args = set(['notest', 'syncdb', 'migrate', 'pip_update', 'norestart'])
     for arg in args:
         if arg not in allowed_args:
             puts('Invalid argument: %s' % arg)
@@ -108,10 +115,13 @@ def push(*args):
         dj_cmd.syncdb()
     if 'migrate' in args:
         dj_cmd.migrate()
-    dj_cmd.compress()
+
+    # execute 'before_restart' callback
+    kwargs.get('before_restart', lambda: None)()
+
     if 'norestart' not in args:
         apache.touch()
-    if 'test' not in args:
+    if 'notest' not in args:
         dj_cmd.test()
 
 def undeploy(confirm=True):
