@@ -1,16 +1,21 @@
 #coding: utf-8
 from __future__ import with_statement
 from fabric.api import *
-from fab_deploy.mysql import mysqldump
-from fab_deploy.utils import inside_project
 
-@inside_project
+from fab_deploy import mysql
+from fab_deploy import utils
+
+
+__all__ = ['migrate', 'manage', 'syncdb', 'compress', 'test', 'coverage', 'command_is_available']
+
+
+@utils.inside_project
 def command_is_available(command):
     with settings(hide('warnings', 'running', 'stdout', 'stderr'), warn_only=True):
         output = run('python manage.py help ' + command)
     return output.succeeded
 
-@inside_project
+@utils.inside_project
 def manage(command):
     """ Runs django management command.
     Example::
@@ -26,9 +31,10 @@ def migrate(params='', do_backup=True):
     """ Runs migrate management command. Database backup is performed
     before migrations if ``do_backup=False`` is not passed. """
     if do_backup:
-        backup_dir = env.conf['ENV_DIR']+'/var/backups/before-migrate'
+        backup_dir = env.conf['ENV_DIR'] + '/var/backups/before-migrate'
         run('mkdir -p '+ backup_dir)
-        mysqldump(backup_dir)
+        with settings(warn_only=True):
+            mysql.mysqldump(backup_dir)
     manage('migrate --noinput %s' % params)
 
 def syncdb(params=''):
@@ -39,7 +45,7 @@ def compress(params=''):
     with settings(warn_only=True):
         manage('synccompress %s' % params)
 
-@inside_project
+@utils.inside_project
 def test(what=''):
     """ Runs 'runtests.sh' script from project root.
     Example runtests.sh content::
