@@ -1,10 +1,14 @@
 from __future__ import with_statement
 from datetime import datetime
 from fabric.api import *
-from fab_deploy.utils import run_as, inside_project, detect_os
-from fab_deploy.system import aptitude_install
+from fab_deploy import utils
+from fab_deploy import system
 
-@run_as('root')
+
+__all__ = ['mysql_execute', 'mysql_install', 'mysql_create_db', 'mysqldump']
+
+
+@utils.run_as('root')
 def mysql_install():
     """ Installs mysql. """
     if _mysql_is_installed():
@@ -13,8 +17,8 @@ def mysql_install():
 
     # this way mysql won't ask for a password on installation
     # see http://serverfault.com/questions/19367/scripted-install-of-mysql-on-ubuntu
-    os = detect_os()
-    aptitude_install('debconf-utils')
+    os = utils.detect_os()
+    system.aptitude_install('debconf-utils')
     passwd=env.conf['DB_PASSWORD']
 
     mysql_versions = {'lenny': '5.0', 'squeeze': '5.1', 'maverick': '5.1'}
@@ -28,14 +32,14 @@ def mysql_install():
     run("echo '%s' | debconf-set-selections" % "\n".join(debconf_defaults))
 
     warn('\n=========\nThe password for mysql "root" user will be set to "%s"\n=========\n' % passwd)
-    aptitude_install('mysql-server')
+    system.aptitude_install('mysql-server')
 
 def _mysql_is_installed():
     with settings(warn_only=True):
         output = run('mysql --version')
     return output.succeeded
 
-@inside_project
+@utils.inside_project
 def mysqldump(dir=None):
     """ Runs mysqldump. Result is stored at <env>/var/backups/ """
     if dir is None:
