@@ -69,16 +69,24 @@ def setup_backports():
 
 @utils.run_as('root')
 def create_linux_account(pub_key_file):
-    """ Creates linux account and setups ssh access. """
+    """ Creates linux account, setups ssh access and pip.conf file. """
     with open(os.path.normpath(pub_key_file), 'rt') as f:
         ssh_key = f.read()
-    username = env.conf['USER']
+
+    username = env.conf.USER
+
+    @utils.run_as(username)
+    def setup_pip_conf():
+        from fab_deploy import virtualenv
+        virtualenv.pip_setup_conf()
+
     with (settings(warn_only=True)):
         run('adduser %s --disabled-password --gecos ""' % username)
-        with cd('/home/' + username):
+        with cd(env.conf.HOME_DIR):
             run('mkdir -p .ssh')
             files.append('.ssh/authorized_keys', ssh_key)
             run('chown -R %s:%s .ssh' % (username, username))
+        setup_pip_conf()
 
 def ssh_add_key(pub_key_file):
     """ Adds a ssh key from passed file to user's authorized_keys on server. """
