@@ -10,7 +10,8 @@ from fabric import state
 from fabric import network
 
 
-__all__ = ['run_as', 'update_env', 'inside_project', 'inside_virtualenv',
+__all__ = ['run_as', 'update_env',
+           'inside_project', 'inside_virtualenv', 'inside_src',
            'delete_pyc', 'print_env', 'detect_os']
 
 def _codename(distname, version, id):
@@ -55,15 +56,16 @@ def run_as(user):
         return inner
     return decorator
 
-def upload_config_template(name, to=None, check_existence=False):
+def upload_config_template(name, to=None, skip_unexistent=False, **kwargs):
     if to is None:
         base_dir = env.conf['ENV_DIR'] + "/etc/"
         run('mkdir -p ' + base_dir)
         to = base_dir + name
     config_template = _config_template_path(name)
-    if check_existence and not os.path.exists(config_template):
+    if config_template is None and skip_unexistent:
         return
-    files.upload_template(config_template, to, env.conf, True)
+    files.upload_template(config_template, to, env.conf, use_jinja=True,
+                          **kwargs)
 
 def update_env():
     """
@@ -157,6 +159,10 @@ def inside_virtualenv(func):
     return inner
 
 def inside_src(func):
+    """
+    Decorator. Use it to perform actions inside remote source dir
+    (repository root) with virtualenv activated.
+    """
     @wraps(func)
     def inner(*args, **kwargs):
         with cd(env.conf.SRC_DIR):
@@ -166,7 +172,8 @@ def inside_src(func):
 
 def inside_project(func):
     """
-    Decorator. Use it to perform actions inside project dir with
+    Decorator. Use it to perform actions inside remote project dir
+    (that's a folder where :file:`manage.py` resides) with
     virtualenv activated::
 
         from fabric.api import *
