@@ -3,10 +3,13 @@ import os.path
 from datetime import datetime
 from fabric.api import *
 
+from fab_deploy import utils
+
+
 BRANCH_OPTION = None
 
 def _exclude_string():
-    excludes = ['config.py', '*.pyc', '*.pyo']
+    excludes = [utils._project_path(env.conf.LOCAL_CONFIG), '*.pyc', '*.pyo']
     exclude_string = " ".join(['--exclude "%s"' % pattern for pattern in excludes])
     if os.path.exists('.excludes'):
         exclude_string =  "-X .excludes " + exclude_string
