@@ -4,7 +4,7 @@ from fab_deploy import apache
 from fab_deploy import utils
 
 
-__all__ = ['pip', 'pip_install', 'pip_update'] # , 'pip_setup_conf']
+__all__ = ['pip', 'pip_install', 'pip_update', 'pip_setup_conf']
 
 
 @utils.inside_src
@@ -28,10 +28,10 @@ def pip_update(what=None, options='', restart=True):
     if restart:
         apache.touch()
 
-#def pip_setup_conf():
-#    """ Sets up pip.conf file """
-#    utils.upload_config_template('pip.conf',
-#        env.conf.HOME_DIR + '/.pip/pip.conf', check_existence=True)
+def pip_setup_conf():
+    """ Sets up pip.conf file """
+    utils.upload_config_template('pip.conf',
+        env.conf.HOME_DIR + '/.pip/pip.conf', skip_unexistent=True)
 
 def virtualenv_create():
     run('mkdir -p envs')
