@@ -33,8 +33,10 @@ if __name__ == '__main__':
 
     FabDeployTest.vm_name = sys.argv[1]
     common_tests = load([BasicTest, SshTest, MysqlTest, CrontabTest])
+    fast_tests = load([FastPrepareServerTest, ApacheSetupTest,
+                       PipSetupTest, NoPipSetupTest])
     suites = {
-        'fast': TestSuite(common_tests + load([FastPrepareServerTest, ApacheSetupTest])),
+        'fast': TestSuite(common_tests + fast_tests),
         'slow': TestSuite(load([DeployTest, CustomLayoutDeployTest])),
         'prepare': TestSuite(common_tests + load([PrepareServerTest])),
     }
