@@ -1,10 +1,9 @@
 from __future__ import absolute_import
 import os
-import urllib2
 from fab_deploy.utils import run_as
 from fabric.api import *
 from fabtest import fab, vbox_urlopen
-from fab_deploy.deploy import deploy_project, push, undeploy, full_deploy
+from fab_deploy.deploy import deploy_project, push, undeploy
 from fab_deploy.mysql import mysql_create_db
 from fab_deploy.apache import (apache_make_config, apache_make_wsgi,
                                apache_restart, apache_install)
@@ -37,6 +36,15 @@ class FabDeployProjectTest(FabDeployTest):
     def assertResponse(self, url, data):
         self.assertEqual(vbox_urlopen(url).read(), data)
 
+    def assertNoFile(self, path):
+        with(settings(warn_only=True)):
+            res = get_file_content(path)
+        self.assertFalse(res.succeeded)
+
+    def assertFileExists(self, path):
+        with(settings(warn_only=True)):
+            self.assertTrue(get_file_content(path))
+
     def setup_conf(self):
         self.cwd = os.getcwd()
         os.chdir(self.project)
@@ -64,7 +72,7 @@ class ApacheSetupTest(FabDeployProjectTest):
 
         foo_port = env.conf.APACHE_PORT
         self.assertPortNotBinded(foo_port)
-        self.assertTrue(get_file_content('/etc/apache2/sites-enabled/foo'))
+        self.assertFileExists('/etc/apache2/sites-enabled/foo')
 
         fab(apache_restart)
         self.assertPortBinded(foo_port)
@@ -86,9 +94,9 @@ class ApacheSetupTest(FabDeployProjectTest):
         self.assertPortBinded(bar_port)
 
     def test_apache_make_wsgi(self):
+        self.assertNoFile(env.conf.ENV_DIR+'/var/wsgi/foo.py')
         fab(apache_make_wsgi)
-        wsgi_file = get_file_content(env.conf.ENV_DIR+'/var/wsgi/foo.py')
-        self.assertTrue(wsgi_file)
+        self.assertFileExists(env.conf.ENV_DIR+'/var/wsgi/foo.py')
 
 
 class DeployTest(FabDeployProjectTest):
@@ -135,3 +143,18 @@ class CustomLayoutDeployTest(FabDeployProjectTest):
         # deploying project again should be possible
         fab(deploy_project)
         self.assertResponse(url, 'foo')
+
+    def test_push_callback(self):
+        url = 'http://foo.example.com/instance/'
+
+        def before_restart():
+            before_restart.called = True
+        before_restart.called = False
+
+        def my_push(*args):
+            return push(*args, before_restart=before_restart)
+
+        fab(foo_site2)
+        fab(deploy_project)
+        fab(my_push)
+        self.assertTrue(before_restart.called)
